@@ -13,6 +13,6 @@ class CloseAppCommand(CommandBase):
     def execute(self):
         requestObj = []
 
-        result = self.executeCommand(requestObj, "Could not execute command")
+        result = self.executeCommand(requestObj)
 
         return SimpleResult(result, "CloseApp was successful", "CloseApp failed")
