@@ -16,6 +16,6 @@ class GetElementLocationCommand(CommandBase):
 
         requestObj = [selector]
 
-        result = self.executeCommand(requestObj, "Could not execute command")
+        result = self.executeCommand(requestObj)
 
         return GetElementLocationResult(result, "GetElementLocation was successful", "GetElementLocation failed")
