@@ -11,6 +11,6 @@ class GetSourceCommand(CommandBase):
     def execute(self):
         requestObj = []
 
-        result = self.executeCommand(requestObj, "Could not execute command")
+        result = self.executeCommand(requestObj)
 
         return GetSourceResult(result, "GetSource was successful", "GetSource failed")   
\ No newline at end of file
