@@ -17,6 +17,6 @@ class InputTextCommand(CommandBase):
 
         requestObj = [selector, text]
 
-        result = self.executeCommand(requestObj, "Could not execute command")
+        result = self.executeCommand(requestObj)
 
         return SimpleResult(result, "InputText was successful", "InputText failed")
