@@ -13,6 +13,6 @@ class MultiTouch_AddCommand(CommandBase):
     def execute(self):
         requestObj = []
 
-        result = self.executeCommand(requestObj, "Could not execute command")
+        result = self.executeCommand(requestObj)
 
         return SimpleResult(result, "MultiTouch_Add was successful", "MultiTouch_Add failed")
