@@ -12,6 +12,6 @@ class MultiTouch_PerformCommand(CommandBase):
     def execute(self):
         requestObj = []
 
-        result = self.executeCommand(requestObj, "Could not execute command")
+        result = self.executeCommand(requestObj)
 
         return SimpleResult(result, "MultiTouch_Perform was successful", "MultiTouch_Perform failed")
