@@ -19,6 +19,6 @@ class PinchCoordinatesCommand(CommandBase):
 
         requestObj = [x, y, length]
 
-        result = self.executeCommand(requestObj, "Could not execute command")
+        result = self.executeCommand(requestObj)
 
         return SimpleResult(result, "PinchCoordinates was successful", "PinchCoordinates failed")
