@@ -17,6 +17,6 @@ class TouchAction_MoveToCommand(CommandBase):
 
         requestObj = [x, y]
 
-        result = self.executeCommand(requestObj, "Could not execute command")
+        result = self.executeCommand(requestObj)
 
         return SimpleResult(result, "TouchAction_MoveTo was successful", "TouchAction_MoveTo failed")
