@@ -16,6 +16,6 @@ class TouchAction_PressElementCommand(CommandBase):
 
         requestObj = [selector]
 
-        result = self.executeCommand(requestObj, "Could not execute command")
+        result = self.executeCommand(requestObj)
 
         return SimpleResult(result, "TouchAction_PressElement was successful", "TouchAction_PressElement failed")
