@@ -15,6 +15,6 @@ class ZoomElementCommand(CommandBase):
 
         requestObj = [selector]
 
-        result = self.executeCommand(requestObj, "Could not execute command")
+        result = self.executeCommand(requestObj)
 
         return SimpleResult(result, "ZoomElement was successful", "ZoomElement failed")
