@@ -1,12 +1,16 @@
 from .AddCapabilityCommand import AddCapabilityCommand
 from .Android_SendKeyCodeCommand import Android_SendKeyCodeCommand
+from .ClearElementCommand import ClearElementCommand
 from .ClickElementCommand import ClickElementCommand
 from .ClickPositionCommand import ClickPositionCommand
 from .CloseAppCommand import CloseAppCommand
 from .RemoveAppCommand import RemoveAppCommand
 from .FindElementCommand import FindElementCommand
+from .GetAppiumSettingsCommand import GetAppiumSettingsCommand
+from .GetElementCommand import GetElementCommand
 from .GetElementAttributeCommand import GetElementAttributeCommand
 from .GetElementLocationCommand import GetElementLocationCommand
+from .GetElementsCommand import GetElementsCommand
 from .GetElementSizeCommand import GetElementSizeCommand
 from .GetOrientationCommand import GetOrientationCommand
 from .GetScreenSizeCommand import GetScreenSizeCommand
@@ -25,6 +29,7 @@ from .ResetAppCommand import ResetAppCommand
 from .RunAppInBackgroundCommand import RunAppInBackgroundCommand
 from .ScreenshotBMPCommand import ScreenshotBMPCommand
 from .ScreenShotJPGCommand import ScreenShotJPGCommand
+from .SetAppiumSettingsCommand import SetAppiumSettingsCommand
 from .SetOrientationCommand import SetOrientationCommand
 from .StartDeviceLoggingCommand import StartDeviceLoggingCommand
 from .StopDeviceLoggingCommand import StopDeviceLoggingCommand
